@@ -113,7 +113,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                     .unwrap();
 
                 ctx.start_transaction().await.unwrap();
-                match Checkout::create(&mut ctx, params.currency.clone()).await {
+                match Checkout::create(&mut ctx, params.currency.clone(), params.contact.clone(), params.shipping_address.clone()).await {
                     Ok(co) => {
                         ctx.set_checkout(&co.id, &co).await.unwrap();
                         ctx.commit_transaction().await.unwrap();
